#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai
version:              3.2.4
visibility:           public
id:                   wai-3.2.4-7YbaDdPfmbRIZrux7wwPLM
key:                  wai-3.2.4-7YbaDdPfmbRIZrux7wwPLM
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  7355aa516172f407be0c48df365b5db8
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai
hs-libraries:         HSwai-3.2.4-7YbaDdPfmbRIZrux7wwPLM
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-types-0.12.4-G7h7u8FYl0yCakR0583rKK
    network-3.1.4.0-C8IvtFvf3OVKggpOXnCQiO text-2.0.2
    vault-0.3.1.6-Z2XWq6J1AyHRsjuCxBwNE

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

